| Title: | 'Probability Distribution Shiny' |
|---|---|
| Description: | Interactive shiny application for working with Probability Distributions. Calculations and Graphs are provided. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-23 06:20:11 UTC |
| Source: | https://github.com/cran/PDShiny |
PDShiny() loads interactive user interface built using R shiny.
PDShiny()PDShiny()
Start PDShiny
The interactive user interface is to provide an easy way for people who are learning Probability Distributions. Includes example data for testing out a few example analysis.
Nothing
## Not run: library(shiny) PDShiny() ## End(Not run)## Not run: library(shiny) PDShiny() ## End(Not run)